Skip to contents

Here, we use pgchecksum, which we created when testing PRIO-GRID, and test it against a similar method for your own local files. This is to verify that you are using the same files as we used to build PRIO-GRID.

Usage

check_pgsourcefiles()

Value

data.frame

Examples

res <- check_pgsourcefiles()
#> Error in pg_rawfolder(): Raw data folder is not set. Use pg_set_rawfolder(path) to set it.