Create matrix with index numbering conventions as for PRIO-GRID.
Source:R/utility.R
create_pg_indices.RdCreate matrix with index numbering conventions as for PRIO-GRID.
Usage
create_pg_indices(config = pg_current_config())Arguments
- config
A
pg_configobject. Defaults topg_current_config().