Skip to contents

This function processes CRU TS v4.09 potential evapotranspiration (PET) data by aggregating it temporally and spatially to match PRIO-GRID specifications.

This function processes CRU TS v4.09 potential evapotranspiration (PET) data by aggregating it temporally and spatially to match PRIO-GRID specifications.

Usage

gen_cru_pet()

gen_cru_pet()

Value

A SpatRaster object with PRIO-GRID spatio-temporal resolution.

A SpatRaster object with PRIO-GRID spatio-temporal resolution.

Examples

if (FALSE) { # \dontrun{
r <- gen_cru_pet()
} # }

if (FALSE) { # \dontrun{
r <- gen_cru_pet()
} # }