This function processes CRU TS v4.09 precipitation (PRE) data by aggregating it temporally and spatially to match PRIO-GRID specifications.
Usage
gen_cru_pre(config = pg_current_config())This function processes CRU TS v4.09 precipitation (PRE) data by aggregating it temporally and spatially to match PRIO-GRID specifications.
gen_cru_pre(config = pg_current_config())