Skip to contents

Creates a PRIO-GRID raster representing the fraction of each cell covered by all types of disputed areas from the Natural Earth Admin 0 Breakaway and Disputed Areas dataset. The dataset does not include temporal information, so all disputes are treated as current/undated.

Usage

gen_ne_disputed_area_share()

Value

A single-layer SpatRaster object

Details

This function is a convenience wrapper around ne_disputed_area_share, automatically using type = "all" to combine all disputed area types into a single raster layer.

References

Natural Earth (2024). “Admin 0 - Breakaway and Disputed Areas. Made with Natural Earth. Free Vector and Raster Map Data.”

Examples

if (FALSE) { # \dontrun{
# Generate raster covering all disputed areas
rast <- gen_ne_disputed_area_share()
terra::plot(rast, main = "PRIO-GRID Coverage: All Disputed Areas")
} # }