Skip to contents

A convenience wrapper for side that extracts the share of the local population belonging to politically excluded ethnic groups.

Usage

gen_side_excluded(config = pg_current_config())

Arguments

config

A pg_config object. Defaults to pg_current_config.

Value

A SpatRaster with excluded population shares for each PRIO-GRID cell. See side for full documentation.

See also

side for full documentation and parameters