Creates a 6-character MD5 hash of the current temporal options from config. Rounds end_date to avoid creating new hashes for small date changes.
Usage
get_temporal_hash(config = pg_current_config())Creates a 6-character MD5 hash of the current temporal options from config. Rounds end_date to avoid creating new hashes for small date changes.
get_temporal_hash(config = pg_current_config())