Skip to contents

This function reads administrative boundary shapefiles from the geoBoundaries global database (version 5.0.0). The data are unzipped to a temporary directory and returned as an sf object.

Usage

read_geoboundaries()

Value

An sf object containing global administrative boundary geometries from geoBoundaries.

References

Runfola D, Anderson A, Baier H, Crittenden M, Dowker E, Fuhrig S, Goodman S, Grimsley G, Layko R, Melville G, Mulder M, Oberman R, Panganiban J, Peck A, Seitz L, Shea S, Slevin H, Youngerman R, Hobbs L (2020). “geoBoundaries: A Global Database of Political Administrative Boundaries.” PLOS ONE, 15(4), e0231866. ISSN 1932-6203. doi:10.1371/journal.pone.0231866 .

See also

get_pgfile for file retrieval, st_read for spatial data input

Examples

if (FALSE) { # \dontrun{
gb <- read_geoboundaries()
} # }