Generate PRIO-GRID Compatible CRU Potential Evapotranspiration Data
Source:R/data_cru.R, R/data_crupet.R
gen_cru_pet.RdThis function processes CRU TS v4.09 potential evapotranspiration (PET) data by aggregating it temporally and spatially to match PRIO-GRID specifications.
This function processes CRU TS v4.09 potential evapotranspiration (PET) data by aggregating it temporally and spatially to match PRIO-GRID specifications.
Value
A SpatRaster object with PRIO-GRID spatio-temporal resolution.
A SpatRaster object with PRIO-GRID spatio-temporal resolution.