Generate PRIO-GRID Compatible CRU Precipitation Data
Source:R/data_cru.R, R/data_crupre.R
gen_cru_pre.RdThis function processes CRU TS v4.09 precipitation (PRE) data by aggregating it temporally and spatially to match PRIO-GRID specifications.
This function processes CRU TS v4.09 precipitation (PRE) data by aggregating it temporally and spatially to match PRIO-GRID specifications.
Value
A SpatRaster object with PRIO-GRID spatio-temporal resolution.
A SpatRaster object with PRIO-GRID spatio-temporal resolution.