The start date is the last observed date in the first interval of the intervals you want to capture. E.g., if start date is 31 January 2010 with 1 month resolution, then the first interval goes from 1 January 2010 to 31 January 2010. The intervals are not necessary equal length.
Usage
pg_date_intervals(
start_date = pgoptions$get_start_date(),
end_date = pgoptions$get_end_date(),
temporal_resolution = pgoptions$get_temporal_resolution()
)Arguments
- from
starting date
- to
end date
- by
increment of sequence. See details in base::seq.Date.
Examples
pg_date_intervals()
#> [1] 2022-11-01 UTC--2023-01-31 UTC 2023-02-01 UTC--2023-04-30 UTC
#> [3] 2023-05-01 UTC--2023-07-31 UTC 2023-08-01 UTC--2023-10-31 UTC
#> [5] 2023-11-01 UTC--2024-01-31 UTC 2024-02-01 UTC--2024-04-30 UTC
#> [7] 2024-05-01 UTC--2024-07-31 UTC 2024-08-01 UTC--2024-10-31 UTC
#> [9] 2024-11-01 UTC--2025-01-31 UTC 2025-02-01 UTC--2025-04-30 UTC
#> [11] 2025-05-01 UTC--2025-07-31 UTC